﻿using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using SoapStudentServiceIntegrationTest.ServiceReference1;

namespace SoapStudentServiceIntegrationTest
{

    // Before running the test:
    // You must setup a proper service reference to the SOAP service
    [TestClass]
    public class UnitTest1
    {
        private static readonly StudentServiceClient Service = new StudentServiceClient();

        [TestCleanup]
        public void ClearAfterEachMethod()
        {
            Service.Clear();
        }

        [ClassCleanup]
        public static void CloseConnectionToService()
        {
            Service.Close();
        }

        [TestMethod]
        public void GetAllStudentsTest()
        {
            Student st = Service.AddStudent("Anders", 1);
            Student st2 = Service.AddStudent("Bent", 4);
            IEnumerable<Student> students = Service.GetAllStudents();
            Assert.AreEqual(2, students.Count());
        }

        [TestMethod]
        public void AddStudentTest()
        {
            Student st = Service.AddStudent("Anders", 1);
            Assert.AreEqual("Anders", st.Name);
            Assert.AreEqual(1, st.Semester);
        }

        [TestMethod]
        public void FindStudentByIdTest()
        {
            Student st = Service.AddStudent("Anders", 1);
            Assert.AreEqual(1, Service.GetAllStudents().Count());
            Student st2 = Service.FindStudentById(st.Id);
            Assert.AreEqual(st.Id, st2.Id);
        }

        [TestMethod]
        public void FindStudentByNameTest()
        {
            Student st = Service.AddStudent("Anders", 1);
            Student st2 = Service.AddStudent("Bent", 4);
            IEnumerable<Student> eStudents = Service.FindStudentByName("e");
            Assert.AreEqual(2, eStudents.Count());
        }

        [TestMethod]
        public void RemoveStudentTest()
        {
            Student st = Service.AddStudent("Anders", 1);
            Student st2 = Service.AddStudent("Bent", 4);
            bool removed = Service.RemoveStudent(st.Id);
            Assert.IsTrue(removed);
            Assert.AreEqual(1, Service.GetAllStudents().Count());

            removed = Service.RemoveStudent(44);
            Assert.IsFalse(removed);
        }

        [TestMethod]
        public void EditStudentTest()
        {
            Student st = Service.AddStudent("Anders", 1);
            bool changed = Service.EditStudent(st.Id, "Anders B", 1);
            Assert.IsTrue(changed);
            Student s = Service.FindStudentById(st.Id);
            Assert.AreEqual("Anders B", s.Name);

            changed = Service.EditStudent(42, "Peter", 6);
            Assert.IsFalse(changed);
        }
    }
}
